@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: scene.R 531 2006-10-09 16:28:07Z dmurdoch $
+## $Id: scene.R 539 2006-12-23 19:15:46Z dmurdoch $
 ##
 
 ##
@@ -21,10 +21,9 @@ rgl.clear <- function( type = "shapes" )
 
   idata <- as.integer(c(length(type), type))
 
-  ret <- .C( "rgl_clear", 
+  ret <- .C( rgl_clear, 
     success = as.integer(FALSE),
-    idata,
-    PACKAGE="rgl"
+    idata
   )
   
   if ( 4 %in% type ) # viewpoint
@@ -47,10 +46,9 @@ rgl.pop <- function( type = "shapes", id = 0)
   for (i in id) {
     idata <- as.integer(c(type, i))
 
-    ret <- .C( "rgl_pop",
+    ret <- .C( rgl_pop,
       success = as.integer(FALSE),
-      idata, 
-      PACKAGE="rgl"
+      idata
     )
 
     if (! ret$success)
@@ -62,11 +60,10 @@ rgl.ids <- function( type = "shapes" )
 {
   type <- rgl.enum.nodetype(type)
   
-  count <- .C( "rgl_id_count", as.integer(type), count = integer(1),
-                               PACKAGE="rgl")$count
+  count <- .C( rgl_id_count, as.integer(type), count = integer(1))$count
   
-  as.data.frame( .C( "rgl_ids", as.integer(type), id=integer(count), 
-                                type=rep("",count), PACKAGE="rgl" )[2:3] )
+  as.data.frame( .C( rgl_ids, as.integer(type), id=integer(count), 
+                                type=rep("",count) )[2:3] )
 }
 
 ##
@@ -93,11 +90,10 @@ rgl.viewpoint <- function( theta = 0.0, phi = 15.0, fov = 60.0, zoom = 1.0, scal
   idata <- as.integer(c(interactive,polar))
   ddata <- as.numeric(c(theta,phi,fov,zoom,scale,userMatrix[1:16]))
 
-  ret <- .C( "rgl_viewpoint",
+  ret <- .C( rgl_viewpoint,
     success = as.integer(FALSE),
     idata,
-    ddata,
-    PACKAGE="rgl"
+    ddata
   )
 
   if (! ret$success)
@@ -117,10 +113,9 @@ rgl.bg <- function(sphere=FALSE, fogtype="none", color=c("black","white"), back=
 
   idata   <- as.integer(c(sphere,fogtype))
 
-  ret <- .C( "rgl_bg", 
+  ret <- .C( rgl_bg, 
     success = as.integer(FALSE),
-    idata,
-    PACKAGE="rgl"
+    idata
   )
 
   if (! ret$success)
@@ -177,7 +172,7 @@ rgl.bbox <- function(
   idata <- as.integer(c(xticks,yticks,zticks, xlen, ylen, zlen, marklen.rel))
   ddata <- as.numeric(c(xunit, yunit, zunit, marklen, expand))
 
-  ret <- .C( "rgl_bbox",
+  ret <- .C( rgl_bbox,
     success = as.integer(FALSE),
     idata,
     ddata,
@@ -186,8 +181,7 @@ rgl.bbox <- function(
     as.numeric(yat),
     as.character(ylab),
     as.numeric(zat),
-    as.character(zlab),
-    PACKAGE="rgl"
+    as.character(zlab)
   )
 
   if (! ret$success)
@@ -211,11 +205,10 @@ rgl.light <- function( theta = 0, phi = 0, viewpoint.rel = TRUE, ambient = "#FFF
   idata <- as.integer(c(viewpoint.rel, ambient, diffuse, specular))
   ddata <- as.numeric(c(theta, phi))
 
-  ret <- .C( "rgl_light",
+  ret <- .C( rgl_light,
     success = as.integer(FALSE),
     idata,
-    ddata,
-    PACKAGE="rgl"
+    ddata
   )
 
   if (! ret$success)
@@ -252,12 +245,11 @@ rgl.primitive <- function( type, x, y=NULL, z=NULL, ... )
     
     idata   <- as.integer( c(type, nvertex ) )
   
-    ret <- .C( "rgl_primitive",
+    ret <- .C( rgl_primitive,
       success = as.integer(FALSE),
       idata,
       as.numeric(vertex),
-      NAOK = TRUE,
-      PACKAGE="rgl"
+      NAOK = TRUE
     );
   
     if (! ret$success)
@@ -337,7 +329,7 @@ rgl.surface <- function( x, z, y, coords=1:3, ... )
 
   parity <- (perm_parity(coords) + (x[2] < x[1]) + (z[2] < z[1]) ) %% 2
   
-  ret <- .C( "rgl_surface",
+  ret <- .C( rgl_surface,
     success = as.integer(FALSE),
     idata,
     as.numeric(x),
@@ -345,8 +337,7 @@ rgl.surface <- function( x, z, y, coords=1:3, ... )
     as.numeric(y),
     as.integer(coords),
     as.integer(parity),
-    NAOK=TRUE,
-    PACKAGE="rgl"
+    NAOK=TRUE
   );
 
   if (! ret$success)
@@ -370,13 +361,12 @@ rgl.spheres <- function( x, y=NULL, z=NULL, radius=1.0,...)
   
   idata <- as.integer( c( nvertex, nradius ) )
    
-  ret <- .C( "rgl_spheres",
+  ret <- .C( rgl_spheres,
     success = as.integer(FALSE),
     idata,
     as.numeric(vertex),    
     as.numeric(radius),
-    NAOK=TRUE,
-    PACKAGE="rgl"
+    NAOK=TRUE
   )
 
   if (! ret$success)
@@ -406,14 +396,13 @@ rgl.texts <- function(x, y=NULL, z=NULL, text, adj = 0.5, justify, ... )
   
   idata <- as.integer(nvertex)
 
-  ret <- .C( "rgl_texts",
+  ret <- .C( rgl_texts,
     success = as.integer(FALSE),
     idata,
     as.double(adj),
     as.character(text),
     as.numeric(vertex),
-    NAOK=TRUE,
-    PACKAGE="rgl"
+    NAOK=TRUE
   )
   
   if (! ret$success)
@@ -437,13 +426,12 @@ rgl.sprites <- function( x, y=NULL, z=NULL, radius=1.0, ... )
   
   idata   <- as.integer( c(ncenter,nradius) )
    
-  ret <- .C( "rgl_sprites",
+  ret <- .C( rgl_sprites,
     success = as.integer(FALSE),
     idata,
     as.numeric(center),
     as.numeric(radius),
-    NAOK=TRUE,
-    PACKAGE="rgl"
+    NAOK=TRUE
   )
 
   if (! ret$success)
@@ -463,15 +451,14 @@ rgl.user2window <- function( x, y=NULL, z=NULL, projection = rgl.projection())
   
   idata  <- as.integer(ncol(points))
   
-  ret <- .C( "rgl_user2window",
+  ret <- .C( rgl_user2window,
   	success = as.integer(FALSE),
 	idata,
 	as.double(points),
 	window=double(length(points)),
 	model=as.double(projection$model),
 	proj=as.double(projection$proj),
-	view=as.integer(projection$view),
-	PACKAGE="rgl"
+	view=as.integer(projection$view)
   )
 
   if (! ret$success)
@@ -489,15 +476,14 @@ rgl.window2user <- function( x, y = NULL, z = 0, projection = rgl.projection())
   window <- rbind(xyz$x,xyz$y,xyz$z)
   idata  <- as.integer(ncol(window))
   
-  ret <- .C( "rgl_window2user",
+  ret <- .C( rgl_window2user,
   	success = as.integer(FALSE),
 	idata,
 	point=double(length(window)),
 	window,
 	model=as.double(projection$model),
 	proj=as.double(projection$proj),
-	view=as.integer(projection$view),
-	PACKAGE="rgl"
+	view=as.integer(projection$view)
   )
 
   if (! ret$success)
@@ -508,11 +494,10 @@ rgl.window2user <- function( x, y = NULL, z = 0, projection = rgl.projection())
 
 rgl.selectstate <- function()
 {
-	ret <- .C( "rgl_selectstate",
+	ret <- .C( rgl_selectstate,
     	success = as.integer(FALSE),
     	state = as.integer(0),
-    	mouseposition = double(4),
-    	PACKAGE="rgl"
+    	mouseposition = double(4)
   	)
 
   	if (! ret$success)
@@ -544,10 +529,9 @@ rgl.setselectstate <- function(state = "current")
 	state = rgl.enum(state, current=0, none = 1, middle = 2, done = 3)
 	idata <- as.integer(c(state))
 	
-	  ret <- .C( "rgl_setselectstate", 
+	  ret <- .C( rgl_setselectstate, 
 	    success = as.integer(FALSE),
-	    state = idata,
-	    PACKAGE="rgl"
+	    state = idata
 	  )
 	
 	  if (! ret$success)
