@@ -15,7 +15,9 @@ rgl.demo.envmap <- function()
   surface3d( 10*1:nrow(volcano),10*1:ncol(volcano),5*volcano
   , texture=system.file("textures/refmap.png",package="rgl")
   , texenvmap=TRUE
+  , color = "white"
   )
 }
+rgl.open()
 rgl.demo.envmap()
 
