@@ -23,11 +23,13 @@ Shape(in_material, in_ignoreExtent, SHAPE)
   material.colorPerVertex(true, nvertices);
 
   vertexArray.alloc(nvertices);
+  hasmissing = false;
   for(int i=0;i<nvertices;i++) {
     vertexArray[i].x = (float) in_vertices[i*3+0];
     vertexArray[i].y = (float) in_vertices[i*3+1];
     vertexArray[i].z = (float) in_vertices[i*3+2];
     boundingBox += vertexArray[i];
+    hasmissing |= vertexArray[i].missing();
   }
 }
 
@@ -43,14 +45,38 @@ void PrimitiveSet::drawBegin(RenderContext* renderContext)
 
 void PrimitiveSet::drawAll(RenderContext* renderContext)
 {
-  glDrawArrays(type, 0, nverticesperelement*nprimitives );
-  // FIXME: refactor to vertexArray.draw( type, 0, nverticesperelement*nprimitives );
+  if (!hasmissing)
+    glDrawArrays(type, 0, nverticesperelement*nprimitives );
+    // FIXME: refactor to vertexArray.draw( type, 0, nverticesperelement*nprimitives );
+  else {
+    bool missing = true;
+    for (int i=0; i<nprimitives; i++) {
+      bool skip = false;
+      for (int j=0; j<nverticesperelement; j++) 
+        skip |= vertexArray[nverticesperelement*i + j].missing();
+      if (missing != skip) {
+        missing = !missing;
+        if (missing) glEnd();
+        else glBegin(type);
+      }
+      if (!missing) 
+        for (int j=0; j<nverticesperelement; j++)
+          glArrayElement( nverticesperelement*i + j );
+    }
+    if (!missing) glEnd();
+  }              
 }
 
 // ---------------------------------------------------------------------------
 
 void PrimitiveSet::drawElement(RenderContext* renderContext, int index)
 {
+  if (hasmissing) {
+    bool skip = false;
+    for (int j=0; j<nverticesperelement; j++) 
+      skip |= vertexArray[index*nverticesperelement + j].missing();
+    if (skip) return;
+  }
   glDrawArrays(type, index*nverticesperelement, nverticesperelement);
   // FIXME: refactor to vertexArray.draw( type, index*nverticesperelement, nverticesperelement );
 }
@@ -114,8 +140,13 @@ FaceSet::FaceSet(
   if (material.lit) {
     normalArray.alloc(nvertices);
     for (int i=0;i<=nvertices-nverticesperelement;i+=nverticesperelement) 
-    {    
-      normalArray[i] = vertexArray.getNormal(i,i+1,i+2);
+    {   
+      if (hasmissing && (vertexArray[i].missing() ||
+                         vertexArray[i+1].missing() ||
+                         vertexArray[i+2].missing()) )
+        normalArray[i] = Vertex(0.0, 0.0, 0.0);
+      else
+        normalArray[i] = vertexArray.getNormal(i,i+1,i+2);
       for (int j=1;j<nverticesperelement;++j)    
         normalArray[i+j] = normalArray[i];
     }
