@@ -23,9 +23,17 @@ public:
   /**
    * overload
    **/
+  
+  /* Check whether scale has changed before rendering */
+  void render(RenderContext* renderContext);
+  
+  /* Sort spheres by depth */
   void renderZSort(RenderContext* renderContext);
   
   void drawElement(RenderContext* renderContext, int i);
+  
+  virtual void getShapeName(char* buffer, int buflen) { strncpy(buffer, "spheres", buflen); };
+
 };
 
 #endif // SPHERESET_HPP
