@@ -64,20 +64,21 @@ void Surface::setNormal(int ix, int iz)
 
   int i = iz*nx + ix;
   int num = 0;
-
-  if (ix < nx-1) {
-    if (iz > 0)     // right/top
-      n[num++] = vertexArray.getNormal(i, i+1, i-nx );
-    if (iz < nz-1)  // right/bottom
-      n[num++] = vertexArray.getNormal(i, i+nx, i+1 );
+  
+  if (!vertexArray[i].missing()) {
+    if (ix < nx-1 && !vertexArray[i+1].missing() ) {
+      if (iz > 0 && !vertexArray[i-nx].missing() )     // right/top
+        n[num++] = vertexArray.getNormal(i, i+1, i-nx );
+      if (iz < nz-1 && !vertexArray[i+nx].missing() )  // right/bottom
+        n[num++] = vertexArray.getNormal(i, i+nx, i+1 );
+    }
+    if (ix > 0 && !vertexArray[i-1].missing() ) { 
+      if (iz > 0 && !vertexArray[i-nx].missing() )     // left/top
+        n[num++] = vertexArray.getNormal(i, i-nx, i-1 );
+      if (iz < nz-1 && !vertexArray[i+nx].missing() )  // left/bottom
+        n[num++] = vertexArray.getNormal(i, i-1, i+nx );
+    }
   }
-  if (ix > 0) { 
-    if (iz > 0)     // left/top
-      n[num++] = vertexArray.getNormal(i, i-nx, i-1 );
-    if (iz < nz-1)  // left/bottom
-      n[num++] = vertexArray.getNormal(i, i-1, i+nx );
-  }
-
   Vertex total(0.0f,0.0f,0.0f);
 
   for(i=0;i<num;i++)
@@ -96,30 +97,39 @@ void Surface::draw(RenderContext* renderContext)
 
   bool use_texcoord = material.texture && !(material.texture->is_envmap() );
   bool use_normal   = material.lit || ( (material.texture) && (material.texture->is_envmap() ) );
-
+  bool missing;
+  
   if (use_texcoord)
     texCoordArray.beginUse();
 
   for(int iz=0;iz<nz-1;iz++) {
-    glBegin(GL_QUAD_STRIP);
+
+    missing = true;
+    
     for(int ix=0;ix<nx;ix++) {
 
       int i;
       
-      // If orientation == 1, we draw iz+1 first, otherwise iz first
-
-      i = (iz+  orientation)*nx+ix;
-      if (use_normal)
-        setNormal(ix, iz+orientation);
-      glArrayElement( i );
-
-      i = (iz+ !orientation)*nx+ix;
-      if (use_normal)
-        setNormal(ix, iz+!orientation);
-      glArrayElement( i );
-
+      if ( missing != (vertexArray[iz*nx+ix].missing() || vertexArray[(iz+1)*nx+ix].missing()) ) {
+        missing = !missing;
+        if (missing) glEnd();
+        else glBegin(GL_QUAD_STRIP);
+      }
+      if (!missing) {
+        // If orientation == 1, we draw iz+1 first, otherwise iz first      
+        i = (iz+  orientation)*nx+ix;
+  
+        if (use_normal)
+          setNormal(ix, iz+orientation);
+        glArrayElement( i );
+  
+        i = (iz+ !orientation)*nx+ix;
+        if (use_normal)
+          setNormal(ix, iz+!orientation);
+        glArrayElement( i );
+      }
     }
-    glEnd();
+    if (!missing) glEnd();
   }
 
   if (use_texcoord)
@@ -132,9 +142,26 @@ void Surface::draw(RenderContext* renderContext)
 
 Vertex Surface::getCenter(int ix, int iz)
 {
-  Vertex accu = vertexArray[iz*nx + ix]     + vertexArray[iz*nx + ix+1] 
-               +vertexArray[(iz+1)*nx + ix] + vertexArray[(iz+1)*nx + ix+1];
-  return accu * 0.25f;  
+  Vertex accu(0.0f,0.0f,0.0f);
+  int num = 0;
+  if ( !vertexArray[iz*nx + ix].missing() ) {
+    accu = accu + vertexArray[iz*nx + ix];
+    num++;
+  }
+  if ( !vertexArray[iz*nx + ix+1].missing() ) {
+    accu = accu + vertexArray[iz*nx + ix+1];
+    num++;
+  }
+  if ( !vertexArray[(iz+1)*nx + ix].missing() ) {
+    accu = accu + vertexArray[(iz+1)*nx + ix];
+    num++;
+  }
+  if ( !vertexArray[(iz+1)*nx + ix+1].missing() ) {
+    accu = accu + vertexArray[(iz+1)*nx + ix+1];
+    num ++;
+  }
+  if (num) accu = accu * (1.0/num);
+  return accu;  
 } 
   
 void Surface::renderZSort(RenderContext* renderContext)
@@ -157,21 +184,27 @@ void Surface::renderZSort(RenderContext* renderContext)
     texCoordArray.beginUse();
 
   for ( std::multimap<float,int>::iterator iter = distanceMap.begin(); iter != distanceMap.end() ; ++ iter ) {
-    glBegin(GL_QUAD_STRIP);
-    for (int i = 0 ; i < 2; ++i ) {
-      int ix = iter->second % nx + i;
-      for (int j = 0 ; j < 2; ++j ) {
-        int iz;
-        if (orientation)
-          iz = iter->second / nx + !j;
-        else
-          iz = iter->second / nx + j;
-        if (use_normal)
-          setNormal(ix, iz);
-        glArrayElement( iz*nx + ix );       
+    int s = iter->second;
+    if (!vertexArray[s].missing() &&
+        !vertexArray[s+1].missing() &&
+        !vertexArray[s+nx].missing() &&
+        !vertexArray[s+nx+1].missing()) {
+      glBegin(GL_QUAD_STRIP);
+      for (int i = 0 ; i < 2; ++i ) {
+        int ix = s % nx + i;
+        for (int j = 0 ; j < 2; ++j ) {
+          int iz;
+          if (orientation)
+            iz = s / nx + !j;
+          else
+            iz = s / nx + j;
+          if (use_normal)
+            setNormal(ix, iz);
+          glArrayElement( iz*nx + ix );       
+        }
       }
+      glEnd();
     }
-    glEnd();
   }  
 
   if (use_texcoord)
