@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: rglview.cpp 502 2006-08-08 22:54:11Z dmurdoch $
+// $Id: rglview.cpp 547 2007-01-06 22:41:23Z dmurdoch $
 
 #include "rglview.h"
 #include "opengl.hpp"
@@ -77,20 +77,21 @@ void RGLView::paint(void) {
   renderContext.time = t;
   renderContext.deltaTime = dt;
 
-  windowImpl->beginGL();
-  scene->render(&renderContext);
+  if (windowImpl->beginGL()) {
+    scene->render(&renderContext);
 
-  glGetDoublev(GL_MODELVIEW_MATRIX,modelMatrix);
-  glGetDoublev(GL_PROJECTION_MATRIX,projMatrix);
-  glGetIntegerv(GL_VIEWPORT,viewport);
+    glGetDoublev(GL_MODELVIEW_MATRIX,modelMatrix);
+    glGetDoublev(GL_PROJECTION_MATRIX,projMatrix);
+    glGetIntegerv(GL_VIEWPORT,viewport);
 
-  if (selectState == msCHANGING)
-    select.render(mousePosition);
-  if (flags & FSHOWFPS && selectState == msNONE)
-    fps.render(renderContext.time, &renderContext );
+    if (selectState == msCHANGING)
+      select.render(mousePosition);
+    if (flags & FSHOWFPS && selectState == msNONE)
+      fps.render(renderContext.time, &renderContext );
 
-  glFinish();
-  windowImpl->endGL();
+    glFinish();
+    windowImpl->endGL();
+  }
 
 //  if (flags & FAUTOUPDATE)
 //    windowImpl->update();
@@ -273,11 +274,12 @@ void RGLView::trackballUpdate(int mouseX, int mouseY)
 
   	rotCurrent = screenToVector(width,height,mouseX,height-mouseY);
 
-	windowImpl->beginGL();
-	viewpoint->updateMouseMatrix(rotBase,rotCurrent);
-	windowImpl->endGL();
+	if (windowImpl->beginGL()) {
+	    viewpoint->updateMouseMatrix(rotBase,rotCurrent);
+	    windowImpl->endGL();
 
-	View::update();
+	    View::update();
+	}
 }
 
 void RGLView::trackballEnd()
@@ -297,11 +299,12 @@ void RGLView::oneAxisUpdate(int mouseX, int mouseY)
 
   	rotCurrent = screenToVector(width,height,mouseX,height/2);
 
-	windowImpl->beginGL();
-	viewpoint->mouseOneAxis(rotBase,rotCurrent,axis[drag-1]);
-	windowImpl->endGL();
+	if (windowImpl->beginGL()) {
+	    viewpoint->mouseOneAxis(rotBase,rotCurrent,axis[drag-1]);
+	    windowImpl->endGL();
 
-	View::update();
+	    View::update();
+	}
 }
 
 void RGLView::polarBegin(int mouseX, int mouseY)
@@ -410,9 +413,8 @@ bool RGLView::snapshot(PixmapFileFormatID formatID, const char* filename)
 {
   bool success = false;
 
-  if ( (formatID < PIXMAP_FILEFORMAT_LAST) && (pixmapFormat[formatID]) ) {
-
-    windowImpl->beginGL();
+  if ( (formatID < PIXMAP_FILEFORMAT_LAST) && (pixmapFormat[formatID]) 
+      && windowImpl->beginGL() ) {
 
     // alloc pixmap memory
 
@@ -424,18 +426,16 @@ bool RGLView::snapshot(PixmapFileFormatID formatID, const char* filename)
 
     glPushAttrib(GL_PIXEL_MODE_BIT);
 
-    glReadBuffer(GL_BACK);
+    glReadBuffer(GL_FRONT);
     glPixelStorei(GL_PACK_ALIGNMENT, 1);
     glReadPixels(0,0,width,height,GL_RGB, GL_UNSIGNED_BYTE, (GLvoid*) snapshot.data);
 
     glPopAttrib();
 
-    snapshot.save( pixmapFormat[formatID], filename );
+    success = snapshot.save( pixmapFormat[formatID], filename );
 
     windowImpl->endGL();
 
-    success = true;
-
   }
 
   return success;
@@ -584,37 +584,59 @@ void RGLView::setDefaultMouseFunc()
     setMouseMode(3, mmZOOM);
 }
 
-bool RGLView::postscript(int formatID, const char* filename)
+bool RGLView::postscript(int formatID, const char* filename, bool drawText)
 {
   bool success = false;
 
-  FILE *fp = fopen(filename, "wb");
+  FILE *fp = fopen(filename, "wb");  
+  char *oldlocale = setlocale(LC_NUMERIC, "C");
+  
   GLint buffsize = 0, state = GL2PS_OVERFLOW;
   GLint viewport[4];
+  GLint options = GL2PS_SILENT | GL2PS_SIMPLE_LINE_OFFSET | GL2PS_NO_BLENDING |
+                  GL2PS_OCCLUSION_CULL | GL2PS_BEST_ROOT;
 
-  glGetIntegerv(GL_VIEWPORT, viewport);
+  if (!drawText) options |= GL2PS_NO_TEXT;
+  
+  if (windowImpl->beginGL()) {
+  
+    glGetIntegerv(GL_VIEWPORT, viewport);
  
-  while( state == GL2PS_OVERFLOW ){ 
-    buffsize += 1024*1024;
-    gl2psBeginPage ( "MyTitle", "Generated by rgl", viewport,
-                   formatID, GL2PS_BSP_SORT, GL2PS_SILENT |
-                   GL2PS_SIMPLE_LINE_OFFSET | GL2PS_NO_BLENDING |
-                   GL2PS_OCCLUSION_CULL | GL2PS_BEST_ROOT,
+    while( state == GL2PS_OVERFLOW ){ 
+      buffsize += 1024*1024;
+      gl2psBeginPage ( filename, "Generated by rgl", viewport,
+                   formatID, GL2PS_BSP_SORT, options,
                    GL_RGBA, 0, NULL, 0, 0, 0, buffsize,
                    fp, filename );
 
-    windowImpl->beginGL();
-
-    // redraw:
-
-    paint();
+    
+      if ( drawText ) {
+        // signal gl2ps for text
+        scene->invalidateDisplaylists();
+        if (formatID == GL2PS_PS || formatID == GL2PS_EPS || 
+            formatID == GL2PS_TEX || formatID == GL2PS_PGF)
+      	  renderContext.gl2psActive = GL2PS_POSITIONAL;  
+        else
+          renderContext.gl2psActive = GL2PS_LEFT_ONLY;
+      }
+    
+      // redraw:
+    
+      scene->render(&renderContext);
+      glFinish();
+ 
+      if ( drawText ) {
+        scene->invalidateDisplaylists();
+        renderContext.gl2psActive = GL2PS_NONE;   
+      }
+      success = true;
 
+      state = gl2psEndPage();
+    }
+  
     windowImpl->endGL();
-
-    success = true;
-
-    state = gl2psEndPage();
   }
+  setlocale(LC_NUMERIC, oldlocale);
   
   fclose(fp);
 
